@@ -130,13 +130,13 @@ int main(int argc, char ** argv)
 {
     QApplication app(argc, argv);
 
-    KAboutData aboutData( "keditfiletype", i18n("KEditFileType"), "1.0",
+    KAboutData aboutData( "keditfiletype", i18n("KEditFileType"), PROJECT_VERSION,
        i18n("KDE file type editor - simplified version for editing a single file type"),
        KAboutLicense::GPL,
        i18n("(c) 2000, KDE developers") );
     aboutData.addAuthor(i18n("Preston Brown"), QString(), "pbrown@kde.org");
     aboutData.addAuthor(i18n("David Faure"), QString(), "faure@kde.org");
-    aboutData.setProgramIconName("preferences-desktop-filetype-association");
+    app.setWindowIcon(QIcon::fromTheme("preferences-desktop-filetype-association"));
     KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
